summaryrefslogtreecommitdiffstats
path: root/models/users.js
diff options
context:
space:
mode:
Diffstat (limited to 'models/users.js')
-rw-r--r--models/users.js30
1 files changed, 27 insertions, 3 deletions
diff --git a/models/users.js b/models/users.js
index 08f833b9..46e56ad6 100644
--- a/models/users.js
+++ b/models/users.js
@@ -109,7 +109,14 @@ Users.attachSchema(
},
'profile.hiddenSystemMessages': {
/**
- * does the user wants to hide system messages?
+ * does the user want to hide system messages?
+ */
+ type: Boolean,
+ optional: true,
+ },
+ 'profile.hiddenMinicardLabelText': {
+ /**
+ * does the user want to hide minicard label texts?
*/
type: Boolean,
optional: true,
@@ -359,6 +366,11 @@ Users.helpers({
return profile.hiddenSystemMessages || false;
},
+ hasHiddenMinicardLabelText() {
+ const profile = this.profile || {};
+ return profile.hiddenMinicardLabelText || false;
+ },
+
getEmailBuffer() {
const { emailBuffer = [] } = this.profile || {};
return emailBuffer;
@@ -462,6 +474,14 @@ Users.mutations({
};
},
+ toggleLabelText(value = false) {
+ return {
+ $set: {
+ 'profile.hiddenMinicardLabelText': !value,
+ },
+ };
+ },
+
addNotification(activityId) {
return {
$addToSet: {
@@ -525,6 +545,10 @@ Meteor.methods({
const user = Meteor.user();
user.toggleSystem(user.hasHiddenSystemMessages());
},
+ toggleMinicardLabelText() {
+ const user = Meteor.user();
+ user.toggleLabelText(user.hasHiddenMinicardLabelText());
+ },
changeLimitToShowCardsCount(limit) {
check(limit, Number);
Meteor.user().setShowCardsCountAt(limit);
@@ -946,8 +970,8 @@ if (Meteor.isServer) {
if (Meteor.isServer) {
// Middleware which checks that API is enabled.
JsonRoutes.Middleware.use(function(req, res, next) {
- const api = req.url.search('api');
- if ((api === 1 && process.env.WITH_API === 'true') || api === -1) {
+ const api = req.url.startsWith('/api');
+ if ((api === true && process.env.WITH_API === 'true') || api === false) {
return next();
} else {
res.writeHead(301, { Location: '/' });